<div class="card-grid">
    <div class="card">
        <div class="card-title">Engine Status</div>
        {% if running %}
        <span class="badge badge-running" style="font-size:1.1rem; padding:6px 18px;">Running</span>
        {% else %}
        <span class="badge badge-failed" style="font-size:1.1rem; padding:6px 18px;">Stopped</span>
        {% endif %}
    </div>
    <div class="card">
        <div class="card-title">Uptime</div>
        <div class="stat-value">{{ uptime_fmt }}</div>
    </div>
</div>
