<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}MediaRiver{% endblock %}</title>
    <link rel="stylesheet" href="/static/style.css">
    <script src="/static/htmx.min.js"></script>
</head>
<body>
    <nav class="sidebar">
        <div class="sidebar-brand">MediaRiver</div>
        <ul class="sidebar-nav">
            <li><a href="/" class="{{ 'active' if page == 'dashboard' }}">Dashboard</a></li>
            <li><a href="/files" class="{{ 'active' if page == 'files' }}">Files</a></li>
            <li><a href="/workflows" class="{{ 'active' if page == 'workflows' }}">Workflows</a></li>
            <li><a href="/logs" class="{{ 'active' if page == 'logs' }}">Logs</a></li>
            <li><a href="/settings" class="{{ 'active' if page == 'settings' }}">Settings</a></li>
        </ul>
    </nav>
    <main class="main">
        {% block content %}{% endblock %}
    </main>
</body>
</html>
